BloomFilterStatistics

Struct BloomFilterStatistics 

pub struct BloomFilterStatistics { /* private fields */ }
In memory Parquet Split Block Bloom Filters (SBBF).

This structure implements PruningStatistics and is used to prune Parquet row groups and data pages based on the query predicate.

Implementations

Source

impl BloomFilterStatistics

pub fn new() -> Self

Create an empty BloomFilterStatistics

pub fn with_capacity(capacity: usize) -> Self

Create an empty BloomFilterStatistics with the specified capacity

pub fn insert( &mut self, column: impl Into<String>, sbbf: Sbbf, ty: Type, type_length: i32, )

Add a Bloom filter for the specified column, along with the column’s Parquet physical Type and type length from the column descriptor.